==> FJSVfefpcl-RHEL5-3.1.1-1-all.tar.gz: FJSVfefpcl/UNINSTALL.sh <==
#!/bin/bash
#
#   UNINSTALL.sh : Uninstallation for FJSVfefpcl
#   version      : 2.0.0
#   author       : Makoto Kawakita
#
#   Copyright FUJITSU LIMITED 2010
#
#**************************************************************************
LANG=C; export LANG
LC_ALL=C; export LC_ALL

#-------------------------------------------------------------------------
# Environment definition
#-------------------------------------------------------------------------
DIRNAME="/usr/bin/dirname"
BASENAME="/bin/basename"
UNAME="/bin/uname"
GREP="/bin/grep"
FIND="/usr/bin/find"
SED="/bin/sed"
RPM="/bin/rpm"

BASEDIR=$(cd `$DIRNAME $0` && /bin/pwd)
SHNAME=`$BASENAME $0`

UNAMEM="`$UNAME -m`"

IDXCOM=0
IDXDEF=1
IDXXEN=2

MSGLOG="/tmp/postsetup.log"
MSGID="FJSVfefpcl"

#-------------------------------------------------------------------------
# sub routine
#-------------------------------------------------------------------------
logmsg() {
#    echo "$*" >> $MSGLOG
    echo "$*"
}


#-------------------------------------------------------------------------
# main routine
#-------------------------------------------------------------------------
#
# su ?
#
if [ $EUID != 0 ]; then
    logmsg "$SHNAME: not privileged."
    exit 1
fi


#
# check argument
#
case $# in
  0)
    ;;
  *)
    logmsg "$MSGID: Illegal option."
    logmsg "$MSGID: Usage: $SHNAME"
    exit 1
    ;;
esac


#
# check rpm files
#
if [ $UNAMEM != "x86_64" -a $UNAMEM != "i686" ]; then
    logmsg "$MSGID: $UNAMEM is not supported."
    logmsg "$MSGID: uninstall failed."
    exit 1
fi
for ent in $($FIND $BASEDIR | $GREP "\.$UNAMEM\."); do
    $BASENAME $ent | $GREP "\-kmod-common-" > /dev/null 2>&1
    if [ $? -eq 0 ]; then
        COMM_FP="`echo $ent | $GREP "\-kmod-common-"`"
        continue;
    fi
    $BASENAME $ent | $GREP "\-xen-" > /dev/null 2>&1
    if [ $? -eq 0 ]; then
        KMODXEN_FP="`echo $ent | $GREP "\-xen-"`"
        continue;
    fi
    # default(Intel64) or PAE(x86)
    KMODDEF_FP="`echo $ent`"
done

FPRPM=($COMM_FP $KMODDEF_FP $KMODXEN_FP)
NMRPM=()
NMVL=()
NMPKG=()
for idx in $IDXCOM $IDXDEF $IDXXEN; do
    NMRPM=(${NMRPM[@]} `$BASENAME ${FPRPM[$idx]}`)
    NMVL=(${NMVL[@]} `echo ${NMRPM[$idx]} | $SED -n "s/\.[^\.]*\.rpm$//p"`)
    NMPKG=(${NMPKG[@]} `$RPM -qp --qf '%{NAME}\n' ${FPRPM[$idx]}`)
done


#
# uninstall package
#
RET=0
for idx in $IDXXEN $IDXDEF $IDXCOM; do
    $RPM -q ${NMPKG[$idx]} > /dev/null 2>&1
    if [ $? -eq 0 ]; then
        logmsg "$MSGID: $RPM -e --nodeps ${NMPKG[$idx]}"
        $RPM -e --nodeps ${NMPKG[$idx]} 2>&1
        if [ $? -ne 0 ]; then
            logmsg "$MSGID: Fatal error: Cannot uninstall ${NMPKG[$idx]}."
            RET=1
        fi
    fi
done


if [ $RET -eq 0 ]; then
    logmsg "$MSGID: uninstall completed."
    exit 0
else
    logmsg "$MSGID: uninstall failed."
    exit 1
fi

==> FJSVfefpcl-RHEL6-4.1.6-1-all.tar.gz: FJSVfefpcl/UNINSTALL.sh <==
#!/bin/bash
#
#   UNINSTALL.sh : Uninstallation for FJSVfefpcl
#   version      : 2.1.0
#   author       : Ryosuke Oohara
#
#   Copyright FUJITSU LIMITED 2010
#
#**************************************************************************
LANG=C; export LANG
LC_ALL=C; export LC_ALL

#-------------------------------------------------------------------------
# Environment definition
#-------------------------------------------------------------------------
DIRNAME="/usr/bin/dirname"
BASENAME="/bin/basename"
UNAME="/bin/uname"
GREP="/bin/grep"
FIND="/usr/bin/find"
SED="/bin/sed"
RPM="/bin/rpm"

BASEDIR=$(cd `$DIRNAME $0` && /bin/pwd)
SHNAME=`$BASENAME $0`

UNAMEM="`$UNAME -m`"

IDXCOM=0
IDXDEF=1

MSGLOG="/tmp/postsetup.log"
MSGID="FJSVfefpcl"

#-------------------------------------------------------------------------
# sub routine
#-------------------------------------------------------------------------
logmsg() {
#    echo "$*" >> $MSGLOG
    echo "$*"
}


#-------------------------------------------------------------------------
# main routine
#-------------------------------------------------------------------------
#
# su ?
#
if [ $EUID != 0 ]; then
    logmsg "$SHNAME: not privileged."
    exit 1
fi


#
# check argument
#
case $# in
  0)
    ;;
  *)
    logmsg "$MSGID: Illegal option."
    logmsg "$MSGID: Usage: $SHNAME"
    exit 1
    ;;
esac


#
# check rpm files
#
if [ $UNAMEM != "x86_64" -a $UNAMEM != "i686" ]; then
    logmsg "$MSGID: $UNAMEM is not supported."
    logmsg "$MSGID: uninstall failed."
    exit 1
fi
for ent in $($FIND $BASEDIR | $GREP "\.$UNAMEM\."); do
    $BASENAME $ent | $GREP "\-kmod-common-" > /dev/null 2>&1
    if [ $? -eq 0 ]; then
        COMM_FP="`echo $ent | $GREP "\-kmod-common-"`"
        continue;
    fi
    # default(Intel64) or PAE(x86)
    KMODDEF_FP="`echo $ent`"
done

FPRPM=($COMM_FP $KMODDEF_FP )
NMRPM=()
NMVL=()
NMPKG=()
for idx in $IDXCOM $IDXDEF ; do
    NMRPM=(${NMRPM[@]} `$BASENAME ${FPRPM[$idx]}`)
    NMVL=(${NMVL[@]} `echo ${NMRPM[$idx]} | $SED -n "s/\.[^\.]*\.rpm$//p"`)
    NMPKG=(${NMPKG[@]} `$RPM -qp --qf '%{NAME}\n' ${FPRPM[$idx]}`)
done


#
# uninstall package
#
RET=0
for idx in $IDXDEF $IDXCOM ; do
    $RPM -q ${NMPKG[$idx]} > /dev/null 2>&1
    if [ $? -eq 0 ]; then
        logmsg "$MSGID: $RPM -e --nodeps ${NMPKG[$idx]}"
        $RPM -e --nodeps ${NMPKG[$idx]} 2>&1
        if [ $? -ne 0 ]; then
            logmsg "$MSGID: Fatal error: Cannot uninstall ${NMPKG[$idx]}."
            RET=1
        fi
    fi
done


if [ $RET -eq 0 ]; then
    logmsg "$MSGID: uninstall completed."
    exit 0
else
    logmsg "$MSGID: uninstall failed."
    exit 1
fi
